@@ -2,6 +2,7 @@
 #'
 #' Takes any vector of languoids and return longitude.
 #' @param x A character vector of the languoids (can be written in lower case)
+#' @param glottolog.source A character vector that define which glottolog database is used: "original" or "modified" (by default)
 #' @author George Moroz <agricolamz@gmail.com>
 #' @seealso \code{\link{aff.lang}}, \code{\link{area.lang}}, \code{\link{country.lang}}, \code{\link{iso.lang}}, \code{\link{lat.lang}}
 #' @examples
@@ -11,8 +12,9 @@
 #' long.lang(c("Adyghe", "Russian"))
 #' @export
 
-long.lang <- function(x){
+long.lang <- function(x, glottolog.source = "modified"){
+  ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original, glottolog <- lingtypology::glottolog.modified)
   sapply(x, function(y){
-    ifelse(is.glottolog(y, response = TRUE) == TRUE,
-           lingtypology::glottolog[tolower(lingtypology::glottolog$lang) == tolower(y),]$longitude,
+    ifelse(is.glottolog(y, response = TRUE, glottolog.source = glottolog.source) == TRUE,
+           glottolog[tolower(glottolog$lang) == tolower(y),]$longitude,
            NA)})}
